@@ -43,7 +43,7 @@ our @ISA = qw(Exporter);
     our @EXPORT = @funcs;	## no critic (ProhibitAutomaticExportation)
 }
 
-our $VERSION = '0.002_90';
+our $VERSION = '0.002_91';
 our $XS_VERSION = $VERSION;
 our $ALPHA_VERSION = $VERSION;
 $VERSION =~ s/_//g;
@@ -386,7 +386,7 @@ or equivalently, using the object-oriented interface,
   $pb->clear ();
   $pb->copy ("Hello, sailor!\n");
 
-=head1 CAVEAT
+=head1 CAVEATS
 
 This module is only useful if the script calling it has access to the
 desktop. Otherwise attempts to instantiate a Mac::Pasteboard object will
@@ -396,6 +396,12 @@ ssh connection, and probably from a cron job as well, depending on your
 version of Mac OS X. This restriction appears to apply not only to the
 system clipboard but to privately-created pasteboards.
 
+Beginning with Mac OS 10.6 Snow Leopard, pasteboards could contain
+multiple items. Until I upgrade, this package can only access the first
+item. If your interest is in writing a droplet (that is, an application
+that processes files which are dropped on it), see
+L<the droplet documentation|Mac::Pasteboard::Droplet>.
+
 =head1 DESCRIPTION
 
 This XS module accesses Mac OS X pasteboards, which can be thought of as
